FounderInfo class

Information about an Event Founder

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

FounderInfo({required String name, String? url, String? date})
const
FounderInfo.fromJson(Map<String, dynamic> json)
factory

Properties

date String?
The date the Event was founded
final
hashCode int
The hash code for this object.
no setterinherited
name String
The Founder's name
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
url String?
A link to the Founder
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited